@@ -61,7 +61,7 @@ try:
     print "Results 1-%i:" % matches.size()
 
     for m in matches:
-        print "%i: %i%% docid=%i [%s]" % (m[xapian.MSET_RANK] + 1, m[xapian.MSET_PERCENT], m[xapian.MSET_DID], m[xapian.MSET_DOCUMENT].get_data())
+        print "%i: %i%% docid=%i [%s]" % (m.rank + 1, m.percent, m.docid, m.document.get_data())
 
 except Exception, e:
     print >> sys.stderr, "Exception: %s" % str(e)
